#!/bin/bash

# Update package index
apt update

# Install necessary prerequisites
apt install -y apt-transport-https ca-certificates curl software-properties-common

# Install Docker using the official installation script
curl -fsSL https://get.docker.com | sh

# Start and enable Docker
systemctl start docker
systemctl enable docker

# Verify Docker installation
docker --version

# Create Docker group if it doesn't exist
if ! getent group docker > /dev/null; then
  groupadd docker
fi

# Add the current user to the Docker group
usermod -aG docker $USER

# Install Portainer
docker volume create portainer_data

docker run -d -p 80:9000 --name=portainer --restart=always \
  -v /var/run/docker.sock:/var/run/docker.sock \
  -v portainer_data:/data portainer/portainer-ce

# Verify Portainer installation
docker ps -a

echo "Docker and Portainer have been installed successfully. Portainer is running on port 80."

# End of script
